@@ -418,3 +418,17 @@ def full_page_snapshot(url, dir_snapshot):
     driver.save_screenshot(dir_snapshot + os.path.sep + "screenshot_last_page.png")
     driver.close()
     return page_index
+
+
+def find_line_in_file(file_path, line_content, search_line_number_begin=0):
+    import fileinput
+
+    line_number = 0
+    with fileinput.FileInput(file_path, mode="r") as f:
+        for line in f:
+            line_number = line_number + 1
+            if line_number < search_line_number_begin:
+                continue
+            if line_content == line:
+                return line_number
+    return 0
